/*
 * GCBDesktop.java
 * Company:      suvi.org
 * @author  schneider
 * Created on June 2, 2004, 8:47 AM
 */

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.Vector;

/** A GCBDesktop contains a Menubar, a JDesktop and a StatusBar.
 *  The JDesktop contains JInternalFrames with Messages
 */
public class GCBDesktop extends JFrame
{
    private JDesktopPane desktopPane = new JDesktopPane();
    private JMenuBar menuBar;
    private javax.swing.JMenu fileMenu;
    private javax.swing.JMenuItem fileexitMenuItem;
    private JMenu commandMenu;
    private JMenuItem commandLocalScanMenuItem;
    private JMenuItem commandTargetScanMenuItem;
    private JMenu optionMenu;
    private JMenuItem optionAutoCopy;
    private JMenu helpMenu;
    private JMenuItem helpaboutMenuItem;
    
    private Controll myControll;
    private MessageLocal m_Message;
    private Vector m_RemoteMessageVector;
    private GCBInputInternalFrame m_gbcInputInternalFrame; 
    
    private JPanel statusBar = new JPanel();
    private JLabel m_statusBar = new JLabel("initializing done");
    
    /** Exit Handles */
    private void exitMenuItemActionPerformed(java.awt.event.ActionEvent evt)
    {
      System.exit(0);
    }
    
    /** Creates a new instance of GCBDesktop */
    public GCBDesktop(MessageLocal localMessage, Controll aControll)
    {
     super("Suvi's Global Clipboard");
     this.m_Message = localMessage;
     this.myControll = aControll;
     //Make sure we have nice window decorations.  
     JFrame.setDefaultLookAndFeelDecorated(true);
     JDialog.setDefaultLookAndFeelDecorated(true);
     //Make the big window be indented 50 pixels from each edge of the screen.
     int inset = 100;
     Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
     setBounds(inset, inset, screenSize.width  - inset*2, screenSize.height - inset*2);
     getContentPane().add(desktopPane,BorderLayout.CENTER);
     getContentPane().add(statusBar, BorderLayout.SOUTH);
     desktopPane.setMinimumSize(new java.awt.Dimension(640, 480));
     //Set exit handler
     setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
     //Build JMenuBar    
     setJMenuBar(createMenuBar());
     //Build StatusBar     
     statusBar = new JPanel();
     statusBar.add(m_statusBar);
     this.getContentPane().add(statusBar,BorderLayout.SOUTH);
     //Bringin up Frame to Screen
     this.setVisible(true);
     //Constructing Internal Frames
     this.createFrame();
    }
    
    /** creates the menubar */
    protected JMenuBar createMenuBar()
    {
     menuBar = new javax.swing.JMenuBar();
     fileMenu = new javax.swing.JMenu("File");
     fileexitMenuItem = new javax.swing.JMenuItem("Exit");
     commandMenu = new javax.swing.JMenu("Command");
     commandLocalScanMenuItem = new javax.swing.JMenuItem("scan local subnet");
     commandTargetScanMenuItem = new javax.swing.JMenuItem("scan target...");
     optionMenu = new javax.swing.JMenu("Option");
     optionAutoCopy = new javax.swing.JMenuItem("Automatic Clipboard: OFF");
     helpMenu = new javax.swing.JMenu("Help");
     helpaboutMenuItem = new javax.swing.JMenuItem("About");
   
     //File->exit
     fileexitMenuItem.addActionListener(new java.awt.event.ActionListener()
     {
        public void actionPerformed(java.awt.event.ActionEvent evt)
        {
            exitMenuItemActionPerformed(evt);
        }
     });
     //Command->Scan Target
     commandTargetScanMenuItem.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      { commandTargetScan_actionPerformed(e); }
    });
     //Command->Scan Local
     commandLocalScanMenuItem.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      { commandLocalScan_actionPerformed(e); }
    });
     //Option->Automatic Copy
     optionAutoCopy.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      { optionAutoCopy_actionPerformed(e); }
    });
     //Help->about
     helpaboutMenuItem.addActionListener(new ActionListener()
    {
      public void actionPerformed(ActionEvent e)
      { jMenuHelpAbout_actionPerformed(e); }
    });
     //Menu Bar
     fileMenu.add(fileexitMenuItem);
     menuBar.add(fileMenu);
     menuBar.add(commandMenu);
     commandMenu.add(commandTargetScanMenuItem);
     commandMenu.add(commandLocalScanMenuItem);
     //menuBar.add(optionMenu); //option menu, TO DO
     optionMenu.add(optionAutoCopy);
     helpMenu.add(helpaboutMenuItem);
     menuBar.add(helpMenu);
        
     return menuBar;
    }
    
    
   /**Help | About action performed*/
  public void jMenuHelpAbout_actionPerformed(ActionEvent e)
  {
    MainFrame_AboutBox dlg = new MainFrame_AboutBox(this);
    Dimension dlgSize = dlg.getPreferredSize();
    Dimension frmSize = getSize();
    Point loc = getLocation();
    dlg.setLocation((frmSize.width - dlgSize.width) / 2 + loc.x, (frmSize.height - dlgSize.height) / 2 + loc.y);
    dlg.setModal(true);
    dlg.show();
  }
  /**Command |Scan local subnet*/
  public void commandLocalScan_actionPerformed(ActionEvent e)
  {
    System.out.println("---Scanning IP-Range x.x.x.0 to x.x.x.256---");
    myControll.scanSubnet(); //scanning local subnet
  }
  /**Command |Scan target host*/
  public void commandTargetScan_actionPerformed(ActionEvent e)
  {
    System.out.println("---Scanning specified target---");
    String result = JOptionPane.showInputDialog(this,"Enter an IPAdress or a host name","What's the target?",JOptionPane.QUESTION_MESSAGE);
    System.out.println(result);
    if (result!=null)
    {
     myControll.scanTarget(result);
    }
  }
  /**Option | Automatic Copy*/
  public void optionAutoCopy_actionPerformed(ActionEvent e)
  {
    if (this.m_gbcInputInternalFrame.getAutoCopyClipboard() == true)
    {    
     System.out.println("---Automatic Copy Clipboard to GCB: OFF---");
     this.m_gbcInputInternalFrame.setAutoCopyClipboard(false);
     this.optionAutoCopy.setText("Automatic Clipboard: OFF");
    }
    else
    {
     System.out.println("---Automatic Copy Clipboard to GCB: ON---");
     this.m_gbcInputInternalFrame.setAutoCopyClipboard(true);
     this.optionAutoCopy.setText("Automatic Clipboard: ON");
    }
    
  }
  
  /**add a Message */
  public void addMessage(Message aMessage)
  {
   try
   {
    new GCBInternalFrame(aMessage, desktopPane);
    System.out.println("new partner: " + aMessage.GetSenderName());  //shell
    m_statusBar.setText("new partner: " + aMessage.GetSenderName()); //statusbar
    this.invalidate();
   }
   catch(Exception e)
   { System.out.println(e); }
  }
  /**remove a Message */
  public void removeMessage(Message aMessage)
  {
   // TO DO ver 0.3
  }
    
   /** Create a new internal frame.*/
    protected void createFrame()
    {
     try
     {  
        //Message Window 
        String alphaMessage = " this is the\n alpha\n version of\n suvi's GlobalClipBoard ";
        GCBInternalFrame frame = new GCBInternalFrame("suvi.org",alphaMessage,desktopPane);
        //InputWindow
        m_gbcInputInternalFrame = new GCBInputInternalFrame(m_Message.getSenderNameLocal(),m_Message);
        desktopPane.add(m_gbcInputInternalFrame);
     }
     catch(Exception e)
     { e.printStackTrace(); }
    }
    
}
